package com.iqball.app

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Surface
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import com.google.gson.Gson
import com.iqball.app.api.EitherCallAdapterFactory
import com.iqball.app.api.service.IQBallService
import com.iqball.app.page.RegisterPage
import com.iqball.app.ui.theme.IQBallTheme
import okhttp3.OkHttpClient
import okhttp3.ResponseBody
import retrofit2.Converter
import retrofit2.Retrofit
import retrofit2.converter.gson.GsonConverterFactory
import retrofit2.create
import java.lang.reflect.Type

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        val gson = Gson()

        val retrofit = Retrofit.Builder()
            .addConverterFactory(GsonConverterFactory.create(gson))
            .addCallAdapterFactory(EitherCallAdapterFactory.create(gson))
            .addConverterFactory(object : Converter.Factory() {
                override fun responseBodyConverter(
                    type: Type,
                    annotations: Array<out Annotation>,
                    retrofit: Retrofit
                ): Converter<ResponseBody, *>? {
                    return super.responseBodyConverter(type, annotations, retrofit)
                }
            })
            .baseUrl("http://grospc:5254")
            .client(
                OkHttpClient.Builder()
                    .addInterceptor { it.proceed(it.request()) }
                    .build()
            )
            .build()

        val service = retrofit.create<IQBallService>()

        setContent {
            IQBallTheme {
                // A surface container using the 'background' color from the theme
                Surface(modifier = Modifier.fillMaxSize(), color = MaterialTheme.colorScheme.background) {
                    App(service)
                }
            }
        }
    }
}

@Composable
fun App(service: IQBallService) {
    RegisterPage(service)
}